@@ -12,29 +12,25 @@ sub _version {
         ->selectcol_arrayref('SELECT VERSION()')->[0];
 }
 
-sub _bare_dsn {
+sub _driver_dsn {
     return 'dbi:mysql:' . join ';',
-        map {"$_=$_[0]->{$_}"} grep { exists $_[0]->{$_} } qw( host port );
+        map {"$_=$_[0]->{$_}"} grep { $_[0]->{$_} } qw( host port );
 }
 
 sub dsn {
     return 'dbi:mysql:' . join ';',
-        map( {"$_=$_[0]->{$_}"} grep { exists $_[0]->{$_} } qw( host port ) ),
+        map( {"$_=$_[0]->{$_}"} grep { $_[0]->{$_} } qw( host port ) ),
         "database=$_[1]";
 }
 
-sub essentials {qw< host port username password >}
-
 sub create_database {
-    my ( $self, $dbname, $keep ) = @_;
-    $dbname = $self->available_dbname() if !$dbname;
+    my ( $self ) = @_;
+    my $dbname = $self->available_dbname();
 
-    # create the database if it doesn't exist
-    $self->drh()
+    DBI->install_driver( $self->name() )
         ->func( 'createdb', $dbname,
         join( ':', $self->{host}, $self->{port} ),
         $self->{username}, $self->{password}, 'admin' );
-    $self->register_drop($dbname) if !$keep;
 
     # return the handle
     return Test::Database::Handle->new(
@@ -48,24 +44,21 @@ sub create_database {
 
 sub drop_database {
     my ( $self, $dbname ) = @_;
-    $self->drh()
+
+    DBI->install_driver( $self->name() )
         ->func( 'dropdb', $dbname, join( ':', $self->{host}, $self->{port} ),
         $self->{username}, $self->{password}, 'admin' )
         if grep { $_ eq $dbname } $self->databases();
 }
 
 sub databases {
-    my ($self) = @_;
-    my $databases = DBI->connect( $self->connection_info() )
-        ->selectall_arrayref('SHOW DATABASES');
-    return
-        grep { $_ !~ /^(?:information_schema|mysql)/ } map {@$_} @$databases;
-}
-
-sub cleanup {
-    my ($self) = @_;
-    my $basename = qr/@{[$self->_basename()]}/;
-    $self->drop_database($_) for grep {/$basename/} $self->databases();
+    my ($self)    = @_;
+    my $basename  = qr/^@{[$self->_basename()]}/;
+    my $databases = eval {
+        DBI->connect_cached( $self->connection_info() )
+            ->selectall_arrayref('SHOW DATABASES');
+    };
+    return grep {/$basename/} map {@$_} @$databases;
 }
 
 'mysql';
